@@ -1,13 +1,15 @@
 import SBstoat
 from SBstoat.modelFitter import ModelFitter
-from SBstoat.observationSynthesizer import ObservationSynthesizerRandomErrors
-from SBstoat._helpers import OptimizerMethod
-from SBstoat._parameterManager import Parameter
-from SBstoat.suiteFitter import SuiteFitter, mkSuiteFitter
 from SBstoat.timeseriesPlotter import TimeseriesPlotter, TIME
 from SBstoat.namedTimeseries import NamedTimeseries
 from SBstoat._version import __version__
+import collections
 # Constants
 METHOD_BOTH = SBstoat._constants.METHOD_BOTH
 METHOD_DIFFERENTIAL_EVOLUTION = SBstoat._constants.METHOD_DIFFERENTIAL_EVOLUTION
 METHOD_LEASTSQ = SBstoat._constants.METHOD_LEASTSQ
+# Externalized methods
+class Parameter(SBstoat._modelFitterCore.Parameter):
+    pass
+class OptimizerMethod(SBstoat._helpers.OptimizerMethod):
+    pass
