@@ -19,7 +19,6 @@ from SBstoat._parallelRunner import ParallelRunner
 from SBstoat import _helpers
 
 import multiprocessing
-import time
 import typing
 
 MAX_CHISQ_MULT = 5
@@ -105,7 +104,7 @@ class ModelFitterBootstrap(mfc.ModelFitterCrossValidator):
             msg = "\nCurent value: %f" % MAX_ITERATION_TIME
             self.logger.result(msg)
         else:
-            self.bootstrapResult = BootstrapResult.merge(results, self)
+            self.bootstrapResult = BootstrapResult.merge(results)
             # Update the logger in place
             _ = _helpers.copyObject(self.bootstrapResult.fitter.logger,
                   self.logger)
