@@ -7,7 +7,6 @@ Core logic of model fitter. Does not include plots.
 """
 
 import SBstoat
-from SBstoat._parameterManager import Parameter
 import SBstoat._constants as cn
 from SBstoat._optimizer import Optimizer
 from SBstoat.namedTimeseries import NamedTimeseries, TIME, mkNamedTimeseries
@@ -17,18 +16,51 @@ from SBstoat import rpickle
 from SBstoat import _helpers
 
 import copy
-import inspect
 import lmfit
 import numpy as np
 import tellurium as te
 import typing
 
 # Constants
+PARAMETER_LOWER_BOUND = 0
+PARAMETER_UPPER_BOUND = 10
 MAX_CHISQ_MULT = 5
 PERCENTILES = [2.5, 97.55]  # Percentile for confidence limits
+LOWER_PARAMETER_MULT = 0.95
+UPPER_PARAMETER_MULT = 1.05
 LARGE_RESIDUAL = 1000000
 
 
+##############################
+class Parameter():
+
+    def __init__(self, name, lower=PARAMETER_LOWER_BOUND,
+              value=None, upper=PARAMETER_UPPER_BOUND):
+        self.name = name
+        self.lower = lower
+        self.upper = upper
+        self.value = value
+        if value is None:
+            self.value = (lower + upper)/2.0
+        if self.value <= self.lower:
+            self.lower = LOWER_PARAMETER_MULT*self.value
+        if self.value >= self.upper:
+            self.upper = UPPER_PARAMETER_MULT*self.value
+        if np.isclose(self.lower, 0.0):
+            self.lower = -0.001
+        if np.isclose(self.upper, 0.0):
+            self.upper = 0.001
+
+    def __str__(self):
+        return self.name
+
+    def copy(self, name=None):
+        if name is None:
+            name = self.name
+        return Parameter(name, lower=self.lower, upper=self.upper,
+              value=self.value)
+
+
 class ModelFitterCore(rpickle.RPickler):
 
     def __init__(self, modelSpecification, observedData,
@@ -37,16 +69,16 @@ class ModelFitterCore(rpickle.RPickler):
           bootstrapMethods=None,
           endTime=None,
           fitterMethods=None,
-          isPlot=True,
           logger=Logger(),
           _loggerPrefix="",
+          isPlot=True,
           maxProcess:int=None,
           numFitRepeat=1,
           numIteration:int=10,
           numPoint=None,
           numRestart=0,
-          parameterLowerBound=cn.PARAMETER_LOWER_BOUND,
-          parameterUpperBound=cn.PARAMETER_UPPER_BOUND,
+          parameterLowerBound=PARAMETER_LOWER_BOUND,
+          parameterUpperBound=PARAMETER_UPPER_BOUND,
           selectedColumns=None,
           serializePath:str=None,
           isParallel=True,
@@ -105,14 +137,11 @@ class ModelFitterCore(rpickle.RPickler):
         """
         if modelSpecification is not None:
             # Not the default constructor
-            self._numIteration = numIteration  # Save for copy constructor
-            self._serializePath = serializePath  # Save for copy constructor
             self._loggerPrefix = _loggerPrefix
             self.modelSpecification = modelSpecification
-            self.observedData = observedData
             self.parametersToFit = parametersToFit
-            self.parameterLowerBound = parameterLowerBound
-            self.parameterUpperBound = parameterUpperBound
+            self.lowerBound = parameterLowerBound
+            self.upperBound = parameterUpperBound
             self._maxProcess = maxProcess
             self.bootstrapKwargs = dict(
                   numIteration=numIteration,
@@ -121,9 +150,7 @@ class ModelFitterCore(rpickle.RPickler):
             self._numFitRepeat = numFitRepeat
             self.selectedColumns = selectedColumns
             self.observedTS, self.selectedColumns = self._updateObservedTS(
-                  mkNamedTimeseries(self.observedData))
-            # Check for nan in observedTS
-            self._isObservedNan = np.isnan(np.sum(self.observedTS.flatten()))
+                  mkNamedTimeseries(observedData))
             #
             self.selectedColumns = [c.strip() for c in self.selectedColumns]
             self.numPoint = numPoint
@@ -146,7 +173,6 @@ class ModelFitterCore(rpickle.RPickler):
             self._isParallel = isParallel
             self._isProgressBar = isProgressBar
             self._selectedIdxs = None
-            self._params = self.mkParams()
             # The following are calculated during fitting
             self.roadrunnerModel = None
             self.minimizerResult = None  # Results of minimization
@@ -158,95 +184,6 @@ class ModelFitterCore(rpickle.RPickler):
             #
         else:
             pass
-
-    def copy(self, isKeepLogger=False, isKeepOptimizer=False, **kwargs):
-        """
-        Creates a copy of the model fitter, overridding any argument
-        that is not None.
-        Preserves the user-specified settings and the results
-        of bootstrapping.
-        
-        Parameters
-        ----------
-        isKeepLogger: bool
-        isKeepOptimizer: bool
-        kwargs: dict
-            arguments to override in copy
-        
-        Returns
-        -------
-        ModelFitter
-        """
-        def setValues(names):
-            """
-            Sets the value for a list of names.
-   
-            Parameters
-            ----------
-            names: list-str
-           
-            Returns
-            -------
-            list-object
-            """
-            results = []
-            for name in names:
-                altName = "_%s" % name
-                if name in kwargs.keys():
-                    results.append(kwargs[name])
-                elif name in self.__dict__.keys():
-                    results.append(self.__dict__[name])
-                elif altName in self.__dict__.keys():                    
-                    results.append(self.__dict__[altName])
-                else:
-                    raise RuntimeError("%s: not found" % name)
-            return results
-        #
-        # Get the positional and keyword arguments
-        inspectResult = inspect.getfullargspec(ModelFitterCore.__init__)
-        allArgNames = inspectResult.args[1:]  # Ignore 'self'
-        if inspectResult.defaults is None:
-            numKwarg = 0
-        else:
-            numKwarg = len(inspectResult.defaults)
-        numParg = len(allArgNames) - numKwarg  # positional arguments
-        pargNames = allArgNames[:numParg]
-        kwargNames = allArgNames[numParg:]
-        # Construct the arguments
-        callPargs = setValues(pargNames)
-        callKwargValues = setValues(kwargNames)
-        callKwargs = {n: v for n, v in zip(kwargNames, callKwargValues)}
-        if numKwarg > 0:
-            # Adjust model specification
-            modelSpecificationIdx = pargNames.index("modelSpecification")
-            observedDataIdx = pargNames.index("observedData")
-            modelSpecification = callPargs[modelSpecificationIdx]
-            observedTS = NamedTimeseries(callPargs[observedDataIdx])
-            selectedColumns = callKwargs["selectedColumns"]
-            if not isinstance(modelSpecification, str):
-                try:
-                    modelSpecification = self.modelSpecification.getAntimony()
-                    callPargs[modelSpecificationIdx] = modelSpecification
-                    observedTS, selectedColumns = self._adjustNames(
-                          modelSpecification, observedTS)
-                    callPargs[observedDataIdx] = observedTS
-                    callKwargs["selectedColumns"] = selectedColumns
-                except Exception as err:
-                    self.logger.error("Problem wth conversion to Antimony. Details:",
-                          err)
-                    raise ValueError("Cannot proceed.")
-            #
-            if isKeepLogger:
-                callKwargs["logger"] = self.logger
-        if numParg < 2:
-            callPargs = [None, None]
-        newModelFitter = self.__class__(*callPargs, **callKwargs)
-        if self.optimizer is not None:
-            if isKeepOptimizer:
-                newModelFitter.optimizer = self.optimizer.copyResults()
-        if self.bootstrapResult is not None:
-            newModelFitter.bootstrapResult = self.bootstrapResult.copy()
-        return newModelFitter
  
     def _updateSelectedIdxs(self):
         resultTS = self.simulate()
@@ -309,8 +246,6 @@ class ModelFitterCore(rpickle.RPickler):
         if params is None:
             if self.optimizer is not None:
                 params = self.optimizer.params
-            else:
-                params = self._params
         return params
 
     @staticmethod
@@ -353,8 +288,8 @@ class ModelFitterCore(rpickle.RPickler):
     @classmethod
     def mkParameters(cls, parametersToFit:list,
           logger:Logger=Logger(),
-          parameterLowerBound:float=cn.PARAMETER_LOWER_BOUND,
-          parameterUpperBound:float=cn.PARAMETER_UPPER_BOUND)->lmfit.Parameters:
+          lowerBound:float=PARAMETER_LOWER_BOUND,
+          upperBound:float=PARAMETER_UPPER_BOUND)->lmfit.Parameters:
         """
         Constructs lmfit parameters based on specifications.
 
@@ -362,8 +297,8 @@ class ModelFitterCore(rpickle.RPickler):
         ----------
         parametersToFit: list-Parameter/list-str
         logger: error logger
-        parameterLowerBound: lower value of range for parameters
-        parameterUpperBound: upper value of range for parameters
+        lowerBound: lower value of range for parameters
+        upperBound: upper value of range for parameters
 
         Returns
         -------
@@ -373,15 +308,16 @@ class ModelFitterCore(rpickle.RPickler):
             raise RuntimeError("Must specify at least one parameter.")
         if logger is None:
             logger = logger()
+        lmfitParameters = lmfit.Parameters()
         # Process each parameter
-        elements = []
         for element in parametersToFit:
             # Get the lower bound, upper bound, and initial value for the parameter
             if not isinstance(element, SBstoat.Parameter):
                 element = SBstoat.Parameter(element,
-                      lower=parameterLowerBound, upper=parameterUpperBound)
-            elements.append(element)
-        return SBstoat.Parameter.mkParameters(elements)
+                      lower=lowerBound, upper=upperBound)
+            lmfitParameters.add(element.name,
+                  min=element.lower, max=element.upper, value=element.value)
+        return lmfitParameters
 
     @classmethod
     def initializeRoadrunnerModel(cls, modelSpecification):
@@ -429,43 +365,18 @@ class ModelFitterCore(rpickle.RPickler):
                 logger.error(msg, err)
 
     @classmethod
-    def runSimulation(cls, **kwargs):
-        """
-        Runs a simulation. Defaults to parameter values in the simulation.
-        Returns a NamedTimeseries.
-
-        Return
-        ------
-        NamedTimeseries (or None if fail to converge)
-        """
-        return NamedTimeseries(namedArray=cls.runSimulationNumpy(**kwargs))
-
-    @classmethod
-    def runSimulationDF(cls, **kwargs):
-        """
-        Runs a simulation. Defaults to parameter values in the simulation.
-        Returns a NamedTimeseries.
-
-        Return
-        ------
-        pd.DataFrame
-        """
-        fittedTS = NamedTimeseries(namedArray=cls.runSimulationArr(**kwargs))
-        return fittedTS.to_dataframe()
-
-    @classmethod
-    def runSimulationNumpy(cls, parameters=None,
+    def runSimulation(cls, parameters=None,
           modelSpecification=None,
           startTime=0,
           endTime=5,
           numPoint=30,
           selectedColumns=None,
+          returnDataFrame=True,
           _logger=Logger(),
           _loggerPrefix="",
           ):
         """
         Runs a simulation. Defaults to parameter values in the simulation.
-        Returns a NamedArray
 
         Parameters
        ----------
@@ -481,13 +392,15 @@ class ModelFitterCore(rpickle.RPickler):
             number of points in the simulation
         selectedColumns: list-str
             output columns in simulation
+        returnDataFrame: bool
+            return a DataFrame
         _logger: Logger
         _loggerPrefix: str
 
 
         Return
         ------
-        NamedArray (or None if fail to converge)
+        NamedTimeseries (or None if fail to converge)
         """
         roadrunnerModel = modelSpecification
         if isinstance(modelSpecification, str):
@@ -503,18 +416,25 @@ class ModelFitterCore(rpickle.RPickler):
             if TIME not in newSelectedColumns:
                 newSelectedColumns.insert(0, TIME)
             try:
-                dataArr = roadrunnerModel.simulate(startTime, endTime, numPoint,
+                data = roadrunnerModel.simulate(startTime, endTime, numPoint,
                       newSelectedColumns)
             except Exception as err:
                 _logger.error("Roadrunner exception: ", err)
-                dataArr = None
+                data = None
         else:
             try:
-                dataArr = roadrunnerModel.simulate(startTime, endTime, numPoint)
+                data = roadrunnerModel.simulate(startTime, endTime, numPoint)
             except Exception as err:
-                _logger.exception("Roadrunner exception: %s" % err)
-                dataArr = None
-        return dataArr
+                _logger.exception("Roadrunner exception: %s", err)
+                data = None
+        if data is None:
+            return data
+        fittedTS = NamedTimeseries(namedArray=data)
+        if returnDataFrame:
+            result = fittedTS.to_dataframe()
+        else:
+            result = fittedTS
+        return result
 
     @classmethod
     def rpConstruct(cls):
@@ -573,6 +493,63 @@ class ModelFitterCore(rpickle.RPickler):
         self.roadrunnerModel = None
         return self
 
+    def copy(self, isKeepLogger=False, isKeepOptimizer=False):
+        """
+        Creates a copy of the model fitter.
+        Preserves the user-specified settings and the results
+        of bootstrapping.
+        
+        Parameters
+        ----------
+        isKeepLogger: bool
+        isKeepOptimizer: bool
+        isMinimalCopy: bool
+            copy minimal context for bootstrap
+        
+        Returns
+        -------
+        ModelFitter
+        """
+        if not isinstance(self.modelSpecification, str):
+            try:
+                modelSpecification = self.modelSpecification.getAntimony()
+            except Exception as err:
+                self.logger.error("Problem wth conversion to Antimony. Details:",
+                      err)
+                raise ValueError("Cannot proceed.")
+            observedTS, selectedColumns = self._adjustNames(
+                  modelSpecification, self.observedTS)
+        else:
+            modelSpecification = self.modelSpecification
+            observedTS = self.observedTS.copy()
+            selectedColumns = self.selectedColumns
+        #
+        if isKeepLogger:
+            logger = self.logger
+        elif self.logger is not None:
+            logger = self.logger.copy()
+        else:
+            logger = None
+        newModelFitter = self.__class__(
+              copy.deepcopy(modelSpecification),
+              observedTS,
+              copy.deepcopy(self.parametersToFit),
+              selectedColumns=selectedColumns,
+              fitterMethods=self._fitterMethods,
+              bootstrapMethods=self._bootstrapMethods,
+              parameterLowerBound=self.lowerBound,
+              parameterUpperBound=self.upperBound,
+              logger=logger,
+              isPlot=self._isPlot)
+        if self.optimizer is not None:
+            if isKeepOptimizer:
+                newModelFitter.optimizer = self.optimizer.copyResults()
+        if self.bootstrapResult is not None:
+            newModelFitter.bootstrapResult = self.bootstrapResult.copy()
+        else:
+            newModelFitter.bootstrapResult = None
+        return newModelFitter
+
     def initializeRoadRunnerModel(self):
         """
         Sets self.roadrunnerModel.
@@ -596,25 +573,7 @@ class ModelFitterCore(rpickle.RPickler):
             dct[parameterName] = self.roadrunnerModel.model[parameterName]
         return dct
 
-    def simulate(self, **kwargs):
-        """
-        Runs a simulation. Defaults to parameter values in the simulation.
-
-        Parameters
-       ----------
-        params: lmfit.Parameters
-        startTime: float
-        endTime: float
-        numPoint: int
-
-        Return
-        ------
-        NamedTimeseries
-        """
-        fixedArr = self._simulateNumpy(**kwargs)
-        return NamedTimeseries(namedArray=fixedArr)
-
-    def _simulateNumpy(self, params=None, startTime=None, endTime=None, numPoint=None):
+    def simulate(self, params=None, startTime=None, endTime=None, numPoint=None):
         """
         Runs a simulation. Defaults to parameter values in the simulation.
 
@@ -642,14 +601,15 @@ class ModelFitterCore(rpickle.RPickler):
         if self.roadrunnerModel is None:
             self.initializeRoadRunnerModel()
         #
-        return self.runSimulationNumpy(parameters=params,
+        return ModelFitterCore.runSimulation(parameters=params,
               modelSpecification=self.roadrunnerModel,
               startTime=startTime,
               endTime=endTime,
               numPoint=numPoint,
               selectedColumns=self.selectedColumns,
               _logger=self.logger,
-              _loggerPrefix=self._loggerPrefix)
+              _loggerPrefix=self._loggerPrefix,
+              returnDataFrame=False)
 
     def updateFittedAndResiduals(self, **kwargs)->np.ndarray:
         """
@@ -722,22 +682,21 @@ class ModelFitterCore(rpickle.RPickler):
         """
         if self._selectedIdxs is None:
             self._updateSelectedIdxs()
-        dataArr = ModelFitterCore.runSimulationNumpy(parameters=params,
+        dataTS = ModelFitterCore.runSimulation(parameters=params,
               modelSpecification=self.roadrunnerModel,
               startTime=self.observedTS.start,
               endTime=self.endTime,
               numPoint=self.numPoint,
               selectedColumns=self.selectedColumns,
               _logger=self.logger,
-              _loggerPrefix=self._loggerPrefix)
-        if dataArr is None:
+              _loggerPrefix=self._loggerPrefix,
+              returnDataFrame=False)
+        if dataTS is None:
             residualsArr = np.repeat(LARGE_RESIDUAL, len(self._observedArr))
         else:
-            truncatedArr = dataArr[self._selectedIdxs, 1:]
-            truncatedArr = truncatedArr.flatten()
-            residualsArr = self._observedArr - truncatedArr
-            if self._isObservedNan:
-                residualsArr = np.nan_to_num(residualsArr)
+            truncatedTS = dataTS[self._selectedIdxs]
+            residualsArr = self._observedArr - truncatedTS.flatten()
+            residualsArr = np.nan_to_num(residualsArr)
         return residualsArr
 
     def fitModel(self, params:lmfit.Parameters=None):
@@ -755,10 +714,10 @@ class ModelFitterCore(rpickle.RPickler):
         -------
         f.fitModel()
         """
-        if params is None:
-            params = self.params
         self.initializeRoadRunnerModel()
         if self.parametersToFit is not None:
+            if params is None:
+                params = self.mkParams()
             self.optimizer = Optimizer.optimize(self.calcResiduals, params,
                   self._fitterMethods, logger=self.logger,
                   numRestart=self._numRestart)
@@ -805,13 +764,10 @@ class ModelFitterCore(rpickle.RPickler):
         """
         if parametersToFit is None:
             parametersToFit = self.parametersToFit
-        if parametersToFit is not None:
-            return ModelFitterCore.mkParameters(parametersToFit,
-                  logger=self.logger,
-                  parameterLowerBound=self.parameterLowerBound,
-                  parameterUpperBound=self.parameterUpperBound)
-        else:
-            return None
+        return ModelFitterCore.mkParameters(parametersToFit,
+              logger=self.logger,
+              lowerBound=self.lowerBound,
+              upperBound=self.upperBound)
 
     def _checkFit(self):
         if self.params is None:
